@@ -1,7 +1,6 @@
 """
 Functions for reading FIB-SEM data from Harald Hess' proprietary format
 Adapted from https://github.com/janelia-cosem/FIB-SEM-Aligner/blob/master/fibsem.py
-Copyright (c) 2017, David Hoffman, Davis Bennett
 """
 
 import os
@@ -74,7 +73,7 @@ class _DTypeDict(object):
             self.update(names, formats, offsets)
 
     def update(self, names, formats, offsets):
-        """"""
+        """ """
         if isinstance(names, list):
             if len(names) == len(formats) == len(offsets):
                 self.names.extend(names)
@@ -117,6 +116,10 @@ def _read_header(path):
     # read initial header
     with open(path, mode="rb") as fobj:
         base_header = np.fromfile(fobj, dtype=header_dtype.dtype, count=1)
+
+        if len(base_header) == 0:
+            raise RuntimeError(f"Base header is missing for {fobj.name}")
+
         fibsem_header = FIBSEMHeader(
             **dict(zip(base_header.dtype.names, base_header[0]))
         )
@@ -140,6 +143,13 @@ def _read_header(path):
             # Read in AI channel scaling factors, (col#: AI#), (row#: offset, gain, 2nd order, 3rd order)
             header_dtype.update("Scaling", (">f4", (2, 4)), _scaling_offset)
 
+        if fibsem_header.FileVersion >= 9:
+            header_dtype.update(
+                ["Restart", "StageMove", "FirstX", "FirstY"],
+                [">u1", ">u1", ">i4", ">i4"],
+                [68, 69, 70, 74],
+            )
+
         header_dtype.update(
             ["XResolution", "YResolution"],  # X Resolution  # Y Resolution
             [">u4", ">u4"],
@@ -190,10 +200,22 @@ def _read_header(path):
                 "AI2",  # AI Ch2
                 "AI3",  # AI Ch3
                 "AI4",  # AI Ch4
-                "Notes",  # Read in notes
             ],
-            [">u1", ">u1", ">u1", ">u1", ">S200"],
-            [151, 152, 153, 154, 180],
+            [">u1", ">u1", ">u1", ">u1"],
+            [151, 152, 153, 154],
+        )
+
+        if fibsem_header.FileVersion >= 9:
+            header_dtype.update(
+                ["SampleID"],
+                ["S25"],
+                [155],
+            )
+
+        header_dtype.update(
+            ["Notes"],
+            [">S200"],
+            [180],
         )
 
         if fibsem_header.FileVersion in {1, 2}:
@@ -583,7 +605,13 @@ def _read(path: Union[str, Path]) -> FIBSEMData:
         dtype = ">i2"
 
     try:
-        raw_data = np.memmap(path, dtype=dtype, mode="r", offset=OFFSET, shape=shape,)
+        raw_data = np.memmap(
+            path,
+            dtype=dtype,
+            mode="r",
+            offset=OFFSET,
+            shape=shape,
+        )
     except ValueError:
         # todo: read what data is available
         raw_data = np.zeros(dtype=dtype, shape=shape)
@@ -613,7 +641,7 @@ def read_fibsem(path: Union[str, Path, Iterable[str], Iterable[Path]]):
         return [_read(p) for p in path]
     else:
         raise ValueError(
-            "Path must be an instance of string or pathlib.Path, or iterable of strings / pathlib.Paths"
+            f"Path '{path}' must be an instance of string or pathlib.Path, or iterable of strings / pathlib.Paths"
         )
 
 
@@ -743,7 +771,7 @@ def aggregate_fibsem_metadata(fnames):
 
 
 class FibsemDataset:
-    def __init__(self, filenames: Sequence):
+    def __init__(self, filenames: Sequence[str]):
         """
         Create a representation of a collection of .dat files as a single dataset.
         """
@@ -784,7 +812,9 @@ class FibsemDataset:
         )
         result_data = da.stack([all_extrema.min(0)[:, 0], all_extrema.max(0)[:, 1]])
         result = DataArray(
-            result_data, dims=("stat", "c"), coords={"stat": ["min", "max"]}
+            result_data,
+            dims=("statistic", "channel"),
+            coords={"statistic": ["min", "max"], "channel": [0, 1]},
         )
         return result
 
